==> haskell-gitrev-1.3.1-34-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitrev
version:              1.3.1
visibility:           public
id:                   gitrev-1.3.1-HLNMuiuWFFhIgYmYImJML
key:                  gitrev-1.3.1-HLNMuiuWFFhIgYmYImJML
license:              BSD-3-Clause
maintainer:           acfoltzer@galois.com
author:               Adam C. Foltzer
homepage:             https://github.com/acfoltzer/gitrev
synopsis:             Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.

category:             Development
abi:                  da1e8d88df765b328e65a111184e5efe
exposed:              True
exposed-modules:      Development.GitRev
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gitrev-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gitrev-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gitrev
hs-libraries:         HSgitrev-1.3.1-HLNMuiuWFFhIgYmYImJML
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    directory-1.3.7.1 filepath-1.4.2.2 process-1.6.18.0
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html:         /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gitrev-1.3.1-35-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gitrev.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitrev
version:              1.3.1
visibility:           public
id:                   gitrev-1.3.1-A894QJs696v2EtFduMnCKp
key:                  gitrev-1.3.1-A894QJs696v2EtFduMnCKp
license:              BSD-3-Clause
maintainer:           acfoltzer@galois.com
author:               Adam C. Foltzer
homepage:             https://github.com/acfoltzer/gitrev
synopsis:             Compile git revision info into Haskell projects
description:
    Some handy Template Haskell splices for including the current git hash and branch in the code of your project. Useful for including in panic messages, @--version@ output, or diagnostic info for more informative bug reports.

category:             Development
abi:                  7a5ce4d8d5e6d81818eec8d60f1ece63
exposed:              True
exposed-modules:      Development.GitRev
import-dirs:          /usr/lib/ghc-9.4.8/site-local/gitrev-1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gitrev-1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gitrev-1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gitrev
hs-libraries:         HSgitrev-1.3.1-A894QJs696v2EtFduMnCKp
depends:
    base-4.17.2.1 base-compat-0.13.0-4bY7VGgUDQwFnN0OMsXbDp
    directory-1.3.7.1 filepath-1.4.2.2 process-1.6.18.0
    template-haskell-2.19.0.0

haddock-interfaces:   /usr/share/doc/haskell-gitrev/html/gitrev.haddock
haddock-html:         /usr/share/doc/haskell-gitrev/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
